# FESTIM
[![NumFOCUS](https://img.shields.io/badge/powered%20by-NumFOCUS-orange.svg?style=flat&colorA=E1523D&colorB=007D8A)](https://numfocus.org/)
[![CI](https://github.com/festim-dev/FESTIM/actions/workflows/ci.yml/badge.svg)](https://github.com/festim-dev/FESTIM/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/festim-dev/FESTIM/branch/master/graph/badge.svg?token=AK3A9CV2D3)](https://codecov.io/gh/festim-dev/FESTIM)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square)](https://github.com/psf/black)
![GitHub stars](https://img.shields.io/github/stars/festim-dev/FESTIM.svg?logo=github&label=Stars&logoColor=white)
![GitHub forks](https://img.shields.io/github/forks/festim-dev/FESTIM.svg?logo=github&label=Forks&logoColor=white)

FESTIM (Finite Elements Simulation of Tritium in Materials) is a tool for modeling hydrogen transport in materials. 
It simulates the diffusion and trapping of hydrogen, coupled to heat transfer with [FEniCS](https://fenicsproject.org).


## Getting started

The installation instructions are available [here](https://festim.readthedocs.io/en/latest/installation.html).

## Documentation 

Documentation can be viewed at https://festim.readthedocs.io/

## Tutorials

Visit the FESTIM-workshop to view the available tutorials https://github.com/festim-dev/FESTIM-workshop

## Contact

For questions on how to use FESTIM, visit our [Discourse page](https://festim.discourse.group/)
or join our [Slack](https://join.slack.com/t/festimworkspace/shared_invite/zt-246hw8d6o-htWASLsbdosUo_2nRKCf9g) channel

## Contributing

The guidelines for contributions can be found in the documentation: https://festim.readthedocs.io/en/latest/devguide/index.html

## Roadmap

You can follow the public roadmap on the [FESTIM projects page](https://github.com/festim-dev/FESTIM/projects?query=is%3Aopen).
Moreover, you can check out the development branch (with support of FEniCSx) on the [_fenicsx_](https://github.com/festim-dev/FESTIM/tree/fenicsx) branch.
